"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processAttribute = processAttribute;
const html_validate_1 = require("html-validate");
/* angularjs 1.x directives */
const directives = [
    "checked",
    "class",
    "disabled",
    "href",
    "maxlength",
    "minlength",
    "pattern",
    "readonly",
    "required",
    "selected",
    "src",
    "style",
    "value",
];
const matchBinding = /^\[(attr\.)?([^\]]*)\]/;
/* eslint-disable-next-line security/detect-non-literal-regexp -- not under user control */
const matchNgAttr = new RegExp(`^ng-(?:attr-(.*)|(${directives.join("|")}))$`);
/**
 * Handle ng-xyz, attr-xyz and [xyz] attributes.
 *
 * It yields both the original attribute (as-is) and an aliased attribute
 * xyz. E.g. `ng-src="{{ foo }}"` yields both:
 *
 * - `ng-src="{{ foo }}"`
 * - `src="DynamicValue"`
 */
function* generateDynamicAlias(attr, key) {
    /* passthru original attribute */
    yield attr;
    /* setup ng-attr-xyz alias */
    yield Object.assign(Object.assign({}, attr), { key, value: new html_validate_1.DynamicValue(attr.value), originalAttribute: attr.key });
}
function* processAttribute(attr) {
    /* angular 2.x or later */
    const binding = matchBinding.exec(attr.key);
    if (binding) {
        yield* generateDynamicAlias(attr, binding[2]);
        return;
    }
    /* angularjs 1.x */
    const ngAttr = matchNgAttr.exec(attr.key);
    if (ngAttr) {
        yield* generateDynamicAlias(attr, ngAttr[1] || ngAttr[2]);
        return;
    }
    /* test if attribute contains interpolation */
    /* eslint-disable-next-line sonarjs/slow-regex -- technical debt, should refactor */
    if (typeof attr.value === "string" && /{{.*}}/.exec(attr.value)) {
        yield Object.assign(Object.assign({}, attr), { value: new html_validate_1.DynamicValue(attr.value) });
        return;
    }
    /* passthru original attribute */
    yield attr;
}
//# sourceMappingURL=attribute.js.map